@@ -119,8 +119,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -141,11 +141,11 @@ class S3ToStepFunction(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        deploy_cloud_trail: typing.Optional[bool] = None,
+        deploy_cloud_trail: typing.Optional[builtins.bool] = None,
         event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
     ) -> None:
@@ -175,42 +175,42 @@ class S3ToStepFunction(
 
         jsii.create(S3ToStepFunction, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(self) -> typing.List[aws_cdk.aws_cloudwatch.Alarm]:
         return jsii.get(self, "cloudwatchAlarms")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="stateMachine")
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return jsii.get(self, "stateMachine")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="stateMachineLogGroup")
     def state_machine_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return jsii.get(self, "stateMachineLogGroup")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudtrail")
     def cloudtrail(self) -> typing.Optional[aws_cdk.aws_cloudtrail.Trail]:
         return jsii.get(self, "cloudtrail")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudtrailBucket")
     def cloudtrail_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "cloudtrailBucket")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudtrailLoggingBucket")
     def cloudtrail_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "cloudtrailLoggingBucket")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "s3Bucket")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "s3LoggingBucket")
@@ -233,7 +233,7 @@ class S3ToStepFunctionProps:
         *,
         state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        deploy_cloud_trail: typing.Optional[bool] = None,
+        deploy_cloud_trail: typing.Optional[builtins.bool] = None,
         event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
     ) -> None:
@@ -253,7 +253,7 @@ class S3ToStepFunctionProps:
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(event_rule_props, dict):
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "state_machine_props": state_machine_props,
         }
         if bucket_props is not None:
@@ -272,7 +272,9 @@ class S3ToStepFunctionProps:
         default
         :default: - None
         """
-        return self._values.get("state_machine_props")
+        result = self._values.get("state_machine_props")
+        assert result is not None, "Required property 'state_machine_props' is missing"
+        return result
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -281,16 +283,18 @@ class S3ToStepFunctionProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("bucket_props")
+        result = self._values.get("bucket_props")
+        return result
 
     @builtins.property
-    def deploy_cloud_trail(self) -> typing.Optional[bool]:
+    def deploy_cloud_trail(self) -> typing.Optional[builtins.bool]:
         """Whether to deploy a Trail in AWS CloudTrail to log API events in Amazon S3.
 
         default
         :default: - true
         """
-        return self._values.get("deploy_cloud_trail")
+        result = self._values.get("deploy_cloud_trail")
+        return result
 
     @builtins.property
     def event_rule_props(self) -> typing.Optional[aws_cdk.aws_events.RuleProps]:
@@ -299,7 +303,8 @@ class S3ToStepFunctionProps:
         default
         :default: - None
         """
-        return self._values.get("event_rule_props")
+        result = self._values.get("event_rule_props")
+        return result
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
@@ -308,12 +313,13 @@ class S3ToStepFunctionProps:
         default
         :default: - None
         """
-        return self._values.get("existing_bucket_obj")
+        result = self._values.get("existing_bucket_obj")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
